/*
    This file is part of Frozen Bubble for S60.

    Frozen Bubble for S60 is free software; you can redistribute
    it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    Frozen Bubble for S60 is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Frozen Bubble for S60; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "CExtendedBitmap.h"

inline TInt GetBitmapLineOffset(TInt width){
  return (4 - (width & 3)) & 3;
}

inline TInt Align32bitSize(TInt value){
  if(value & 3)
    value = value + 4 - (value & 3);  
  return value;
}

inline TAny* Align32bit(const TAny *addr){
  TUint pointer = (TUint)(addr);
  if(pointer & 3)
    pointer = pointer + 4 - (pointer & 3);
  return (TAny*)pointer;
}

void CExtendedBitmap::CopyBitmap(CFbsBitmap &iSource, CFbsBitmap &iTarget){
  CFbsBitmapDevice* graphicsDevice = CFbsBitmapDevice::NewL( &iTarget );
  CleanupStack::PushL( graphicsDevice );
  CFbsBitGc* graphicsContext;
  User::LeaveIfError( graphicsDevice->CreateContext( graphicsContext ) );
  graphicsContext->BitBlt( TPoint(0,0), &iSource );
  CleanupStack::Pop( graphicsDevice );
}


void CPrintableExtendedBitmap::DisposeHandles(void){
  if( graphicsContext ){
    delete graphicsContext;
    graphicsContext = NULL;
  }
  if( graphicsDevice ){
    delete graphicsDevice;
    graphicsDevice = NULL;
  }
}

void CPrintableExtendedBitmap::ReallocateHandles(void){
  DisposeHandles();
  graphicsDevice = CFbsBitmapDevice::NewL( GetBitmap() );
  User::LeaveIfError( graphicsDevice->CreateContext( graphicsContext ) );
}

void CPrintableExtendedBitmap::SetBitmap(CFbsBitmap* iBmp){
  CExtendedBitmap::SetBitmap(iBmp);
  ReallocateHandles();
}
