/*
    This file is part of Frozen Bubble for S60.

    Frozen Bubble for S60 is free software; you can redistribute
    it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    Frozen Bubble for S60 is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Frozen Bubble for S60; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef CEXTENDEDBITMAP_H
#define CEXTENDEDBITMAP_H

#include <fbs.h>
#include <gdi.h>
#include <bitdev.h>

typedef TUint16 (*TTransformFunction)(TUint16 iColor);

class CExtendedBitmap:public CBase{
  private:
    CFbsBitmap *iBitmap, *iBitmapAlpha;
    void CopyBitmap(CFbsBitmap &iSource, CFbsBitmap &iTarget);
  public:
    CExtendedBitmap():CBase(){
    }
    CExtendedBitmap(CExtendedBitmap& iBmp):CBase(){
      SetBitmap(iBmp.GetBitmap());
      SetBitmapAlpha(iBmp.GetBitmapAlpha());
    }
    ~CExtendedBitmap(){
      delete iBitmap;
      delete iBitmapAlpha;
    }
    virtual void SetBitmap(CFbsBitmap* iBmp){
      delete iBitmap;
      iBitmap = NULL;
      if( iBmp ){
        iBitmap = new CFbsBitmap();
        iBitmap->Duplicate( iBmp->Handle() );
      }
    }
    void SetBitmapAlpha(CFbsBitmap* iBmp){
      delete iBitmapAlpha;
      iBitmapAlpha = NULL;
      if( iBmp ){
        iBitmapAlpha = new CFbsBitmap();
        iBitmapAlpha->Duplicate( iBmp->Handle() );
      }
    }
    CFbsBitmap* GetBitmap(void) const{
      return iBitmap;
    }
    CFbsBitmap* GetBitmapAlpha(void) const{
      return iBitmapAlpha;
    }
    void BitBlt(CBitmapContext *iGc, const TPoint &aPosition){
      iGc->BitBlt(aPosition, iBitmap);
    }
    void BitBlt(CBitmapContext *iGc, const TPoint &aPosition, const TRect& aRect){
      iGc->BitBlt(aPosition, iBitmap, aRect);
    }
    void BitBltMasked(CBitmapContext *iGc, const TPoint &aPosition){
      iGc->BitBltMasked(aPosition, iBitmap, TRect( TPoint(0,0), iBitmap->SizeInPixels() ), iBitmapAlpha, EFalse);
    }
    void BitBltMasked(CBitmapContext *iGc, const TPoint &aPosition, const TRect& aRect){
      iGc->BitBltMasked(aPosition, iBitmap, aRect, iBitmapAlpha, EFalse);
    }
};

class CPrintableExtendedBitmap:public CExtendedBitmap{
  private:
    CFbsBitmapDevice* graphicsDevice;
    CFbsBitGc* graphicsContext;
    void DisposeHandles(void);
    void ReallocateHandles(void);
  public:
    CPrintableExtendedBitmap():CExtendedBitmap(){
    }
    CPrintableExtendedBitmap(CExtendedBitmap& iBmp):CExtendedBitmap(iBmp){
      ReallocateHandles();
    }
    ~CPrintableExtendedBitmap(){
      DisposeHandles();
    }
    void SetBitmap(CFbsBitmap* iBmp);
    CFbsBitGc& getGraphicsContext(void){
      return *graphicsContext;
    }
    void CopyFrom(CFbsBitmap &Source){
      graphicsContext->BitBlt( TPoint(0,0), &Source );
    }
};
#endif
