/*
    This file is part of Frozen Bubble for S60.

    Frozen Bubble for S60 is free software; you can redistribute
    it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    Frozen Bubble for S60 is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Frozen Bubble for S60; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "CExtendedFont.h"

const TInt SPACE_LENGTH=6;

TInt CExtendedFont::FindInMap(char c){
  for(TInt i=0; i<59; i++)
    if(characterMap[i] == c)
      return i;
  return -1;
}

CExtendedFont::CExtendedFont(CExtendedBitmap *iBitmap, MFrozenBubbleAction *iActions):CBase(){
  characterMap = "!\"#$%&'()*_,-./0123456789:____?_ABCDEFGHIJKLMNOPQRSTUVWXYZ";
  iFont = iBitmap;
  actions = iActions;
  szFont = iFont->GetBitmap()->SizeInPixels();
}

void CExtendedFont::ConstructL(void){
  // build limits
  CFbsBitmap *bmp = iFont->GetBitmap();
  TSize size = bmp->SizeInPixels();
  TInt cPos=0; TBool isSpace=ETrue;
  for(TInt idx=0; idx<size.iWidth; idx++){
    TRgb color;
    bmp->GetPixel( color, TPoint(idx, 0) );
    if( color.Red() < 32 ) {//red != 31 ){
      if( isSpace ){
        isSpace = EFalse;
        limits[cPos].iPosition = (TInt16)idx;
      }
    } else {
      if( !isSpace ){
        limits[cPos].iSize = (TInt16)(idx-limits[cPos].iPosition);
        cPos++;
        isSpace = ETrue;
      }
    }
  }
}

CExtendedFont::~CExtendedFont(){
  delete iFont;
}

TInt CExtendedFont::GetTextLength(TPtrC8 str){
  TInt length = 0;
  for(TInt ichar=0; ichar<str.Size(); ichar++){
    TInt cmapindex = FindInMap(str[ichar]);
    if( cmapindex != -1 )
      length += limits[cmapindex].iSize;
    else
      length += SPACE_LENGTH;
  }
  return length;
}

void CExtendedFont::Print(TInt x, TInt y, TPtrC8 str){
  TInt xPos = x;
  for(TInt ichar=0; ichar<str.Size(); ichar++){
    TInt cmapindex = FindInMap(str[ichar]);
    if( cmapindex != -1 ){
      TRect rect(TPoint((TInt)limits[cmapindex].iPosition, 0), TSize(limits[cmapindex].iSize, szFont.iHeight));
      actions->BitBlt(BLTTYPE_MASKED, *iFont, TPoint(xPos, y), rect);
      xPos += limits[cmapindex].iSize;
    } else
      xPos += SPACE_LENGTH;
  }
}
