/*
    This file is part of Frozen Bubble for S60.

    Frozen Bubble for S60 is free software; you can redistribute
    it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    Frozen Bubble for S60 is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Frozen Bubble for S60; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __CMIXERTHREAD_H__
#define __CMIXERTHREAD_H__

#include <E32Base.h>
#include <mdaaudiooutputstream.h>
#include <mda\common\audio.h>
#include "TAudioShared.h"

class MyActive;
#include "mikmod.h"
// CMixerThread class takes care of mixing maximum of 16 channels of sampled sound to audio output stream.

class CMixerThread : CBase, MMdaAudioOutputStreamCallback{
public:

  /// Thread entry point
  static TInt ThreadFunction( TAny* aData );

  /// Default destructor
  ~CMixerThread();
  
  /// exception handler function
  /// @param aExc exception code
  void HandleExceptionL( /*TExcType aExc */);
  
private:

  /// Default constructor
  /// @param aData data pointer from creator thread
  CMixerThread( TAny* aData );

  /// Two phased constructor
  /// @param aData data pointer from creator thread
  static CMixerThread* CreateL( TAny* aData );

  /// Second phase constructor
  TInt Construct();

  /// Second phase constructor which can leave
  void ConstructL();

  /// starts mixer
  void StartMixerL();

  /// stops mixer
  void StopMixer();

private: // MMdaAudioOutputStreamCallback
  
  void MaoscPlayComplete( TInt aError );
  void MaoscBufferCopied( TInt aError, const TDesC8& aBuffer );
  void MaoscOpenComplete( TInt aError );

private:
  
  /// Fill mixing buffer with new data
  void FillBufferL();
  
private:

  CTrapCleanup*     iCleanupStack;
  CActiveScheduler*   iActiveScheduler;
  CMdaAudioOutputStream*  iStream;
  TMdaAudioDataSettings iSet;

  TInt16*         iBuffer;  // buffer to CMdaAudioOutput
  TInt*         iMixBuffer; // 32-bit buffer to mixing
  TPtrC8          iBufferPtr; // pointer to iBuffer
  
  TInt          iError;   // contains CMdaAudioOutput errors

  TAudioShared&     iShared;  // reference to shared data with client

  MyActive* iActive;

  // current sample data pointers
  TInt16* iAudioData[ KMaxChannels ];

  // These are shifted by KAudioShift
  TInt iAudioPos[ KMaxChannels ];
  TInt iAudioEnd[ KMaxChannels ];
  TInt iRepStart[ KMaxChannels ];
  TInt iRepEnd[ KMaxChannels ]; 
};
  
#endif
