/*
    This file is part of Frozen Bubble for S60.

    Frozen Bubble for S60 is free software; you can redistribute
    it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    Frozen Bubble for S60 is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Frozen Bubble for S60; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __FROZENBUBBLEDOCUMENT_h__
#define __FROZENBUBBLEDOCUMENT_h__

// INCLUDES
#ifdef UIQ3	
	#include <qikdocument.h>
#else
	#include <akndoc.h>
#endif

// FORWARD DECLARATIONS
class CFrozenBubbleAppUi;
class CEikApplication;


// CLASS DECLARATION

/**
* CFrozenBubbleDocument application class.
* An instance of class CFrozenBubbleDocument is the Document part of the
* AVKON application framework for the FrozenBubble example application.
*/
#ifdef UIQ3	
class CFrozenBubbleDocument : public CQikDocument {
#else
class CFrozenBubbleDocument : public CAknDocument {
#endif
public: // Constructors and destructor

    /**
    * NewL.
    * Two-phased constructor.
    * Construct a CFrozenBubbleDocument for the AVKON application aApp
    * using two phase construction, and return a pointer
    * to the created object.
    * @param aApp Application creating this document.
    * @return A pointer to the created instance of CFrozenBubbleDocument.
    */
    static CFrozenBubbleDocument* NewL( CEikApplication& aApp );

    /**
    * NewLC.
    * Two-phased constructor.
    * Construct a CFrozenBubbleDocument for the AVKON application aApp
    * using two phase construction, and return a pointer
    * to the created object.
    * @param aApp Application creating this document.
    * @return A pointer to the created instance of CFrozenBubbleDocument.
    */
    static CFrozenBubbleDocument* NewLC( CEikApplication& aApp );

    /**
    * ~CFrozenBubbleDocument
    * Virtual Destructor.
    */
    virtual ~CFrozenBubbleDocument();

public: // Functions from base classes

    /**
    * CreateAppUiL
    * From CEikDocument, CreateAppUiL.
    * Create a CFrozenBubbleAppUi object and return a pointer to it.
    * The object returned is owned by the Uikon framework.
    * @return Pointer to created instance of AppUi.
    */
    CEikAppUi* CreateAppUiL();

private: // Constructors

    /**
    * ConstructL
    * 2nd phase constructor.
    */
    void ConstructL();

    /**
    * CFrozenBubbleDocument.
    * C++ default constructor.
    * @param aApp Application creating this document.
    */
    CFrozenBubbleDocument( CEikApplication& aApp );

};

#endif // __FROZENBUBBLEDOCUMENT_h__

// End of File
