/*
    This file is part of Frozen Bubble for S60.

    Frozen Bubble for S60 is free software; you can redistribute
    it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.

    Frozen Bubble for S60 is distributed in the hope that it
    will be useful, but WITHOUT ANY WARRANTY; without even the implied
    warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
    See the GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Frozen Bubble for S60; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __TAUDIOSHARED_H__
#define __TAUDIOSHARED_H__

#include <e32std.h>
#include "TSample.h"
#include "mikmod.h"
const TInt KMaxChannels = 16;
const TInt KAudioShift = 12;

// ENUMERATIONS
enum TMixerCmd {
  ECmdStartMixer = 0,
  ECmdStopMixer,
  ECmdDestroyMixer
};

// TAudioShared is internal type for sound mixer application. This struct is used for inter-thread data trasfer and communication

class TAudioShared {
public:
  /// for thread end signaling
  RSemaphore  iAliveMutex;

  /// for sample attribute change signaling
  RMutex  iMutex;

  /// pause flag
  TBool iPaused;

  /// sample attributes
  TSample iSample[ KMaxChannels ];
  TInt  iVolume[ KMaxChannels ];
  TInt  iFrequency[ KMaxChannels ];
  TBool iPlayStarted[ KMaxChannels ];
  TExcType        iExc;
  TRequestStatus* iStatusPtr;
  
  /// main volume
  TInt  iMainVolume;

  /// Command parameter
  TMixerCmd iCmd;

  /** Music module if playing */
  MODULE* iModule;
  /** Dont play music */
  TBool iModulePaused;
};

#endif


